==> kdevplatform-1.4.1.tbz: lib/cmake/kdevplatform/KDevPlatformTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
SET(CMAKE_IMPORT_FILE_VERSION 1)

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__sublime" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__sublime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__sublime PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kparts"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libsublime.so.6.0.0"
  IMPORTED_SONAME_RELEASE "libsublime.so.6"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__sublime )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__sublime "/usr/local/kde4/lib/libsublime.so.6.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatforminterfaces" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatforminterfaces APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatforminterfaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDE4__kcmutils;KDE4__knotifyconfig;KDE4__threadweaver;KDE4__krosscore"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kparts;KDE4__ktexteditor"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatforminterfaces.so.6.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatforminterfaces.so.6"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatforminterfaces )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatforminterfaces "/usr/local/kde4/lib/libkdevplatforminterfaces.so.6.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformproject" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformproject APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformproject PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformutil;KDevPlatformImport__kdevplatformlanguage;KDE4__kio"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformproject.so.6.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformproject.so.6"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformproject )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformproject "/usr/local/kde4/lib/libkdevplatformproject.so.6.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformlanguage" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformlanguage APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformlanguage PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kparts;KDE4__ktexteditor;KDE4__threadweaver;KDevPlatformImport__kdevplatformutil"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformlanguage.so.6.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformlanguage.so.6"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformlanguage )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformlanguage "/usr/local/kde4/lib/libkdevplatformlanguage.so.6.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformshell" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformshell APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformshell PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDE4__kfile;KDE4__kcmutils;KDE4__kparts;KDE4__knotifyconfig;KDE4__ktexteditor;KDE4__threadweaver;KDE4__krosscore;KDevPlatformImport__kdevplatforminterfaces;KDevPlatformImport__kdevplatformproject;KDevPlatformImport__kdevplatformvcs;KDevPlatformImport__kdevplatformlanguage;KDevPlatformImport__kdevplatformutil;KDevPlatformImport__kdevplatformdocumentation"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformoutputview;KDevPlatformImport__sublime;KDevPlatformImport__kdevplatformdebugger"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformshell.so.6.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformshell.so.6"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformshell )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformshell "/usr/local/kde4/lib/libkdevplatformshell.so.6.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformutil" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformutil APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformutil PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kcmutils;KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformutil.so.6.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformutil.so.6"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformutil )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformutil "/usr/local/kde4/lib/libkdevplatformutil.so.6.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformoutputview" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformoutputview APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformoutputview PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformoutputview.so.6.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformoutputview.so.6"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformoutputview )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformoutputview "/usr/local/kde4/lib/libkdevplatformoutputview.so.6.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformvcs" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformvcs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformvcs PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDE4__kparts;KDevPlatformImport__kdevplatformutil;KDevPlatformImport__kdevplatformproject;KDevPlatformImport__kdevplatformlanguage"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformoutputview;KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformvcs.so.6.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformvcs.so.6"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformvcs )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformvcs "/usr/local/kde4/lib/libkdevplatformvcs.so.6.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformdebugger" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformdebugger APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformdebugger PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__ktexteditor"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces;KDevPlatformImport__kdevplatformutil"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformdebugger.so.6.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformdebugger.so.6"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformdebugger )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformdebugger "/usr/local/kde4/lib/libkdevplatformdebugger.so.6.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformdocumentation" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformdocumentation APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformdocumentation PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformdocumentation.so.6.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformdocumentation.so.6"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformdocumentation )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformdocumentation "/usr/local/kde4/lib/libkdevplatformdocumentation.so.6.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformtests" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformtests APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformtests PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformshell;KDevPlatformImport__kdevplatformlanguage"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformtests.so.6.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformtests.so.6"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformtests )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformtests "/usr/local/kde4/lib/libkdevplatformtests.so.6.0.0" )

# Loop over all imported files and verify that they actually exist
FOREACH(target ${_IMPORT_CHECK_TARGETS} )
  FOREACH(file ${_IMPORT_CHECK_FILES_FOR_${target}} )
    IF(NOT EXISTS "${file}" )
      MESSAGE(FATAL_ERROR "The imported target \"${target}\" references the file
   \"${file}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    ENDIF()
  ENDFOREACH()
  UNSET(_IMPORT_CHECK_FILES_FOR_${target})
ENDFOREACH()
UNSET(_IMPORT_CHECK_TARGETS)

# Commands beyond this point should not need to know the version.
SET(CMAKE_IMPORT_FILE_VERSION)

==> kdevplatform-1.5.1.tbz: lib/cmake/kdevplatform/KDevPlatformTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
SET(CMAKE_IMPORT_FILE_VERSION 1)

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__sublime" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__sublime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__sublime PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kparts"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libsublime.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libsublime.so.7"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__sublime )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__sublime "/usr/local/kde4/lib/libsublime.so.7.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatforminterfaces" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatforminterfaces APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatforminterfaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDE4__kcmutils;KDE4__knotifyconfig;KDE4__threadweaver;KDE4__krosscore"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kparts;KDE4__ktexteditor"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatforminterfaces.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatforminterfaces.so.7"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatforminterfaces )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatforminterfaces "/usr/local/kde4/lib/libkdevplatforminterfaces.so.7.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformproject" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformproject APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformproject PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformutil;KDevPlatformImport__kdevplatformlanguage;KDE4__kio"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformproject.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformproject.so.7"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformproject )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformproject "/usr/local/kde4/lib/libkdevplatformproject.so.7.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformlanguage" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformlanguage APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformlanguage PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kparts;KDE4__ktexteditor;KDE4__threadweaver;KDE4__knewstuff3;KDevPlatformImport__kdevplatformutil;grantlee_core"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformlanguage.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformlanguage.so.7"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformlanguage )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformlanguage "/usr/local/kde4/lib/libkdevplatformlanguage.so.7.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformshell" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformshell APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformshell PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDE4__kfile;KDE4__kcmutils;KDE4__kparts;KDE4__knotifyconfig;KDE4__ktexteditor;KDE4__threadweaver;KDE4__krosscore;KDevPlatformImport__kdevplatforminterfaces;KDevPlatformImport__kdevplatformproject;KDevPlatformImport__kdevplatformvcs;KDevPlatformImport__kdevplatformlanguage;KDevPlatformImport__kdevplatformutil;KDevPlatformImport__kdevplatformdocumentation"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformoutputview;KDevPlatformImport__sublime;KDevPlatformImport__kdevplatformdebugger"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformshell.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformshell.so.7"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformshell )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformshell "/usr/local/kde4/lib/libkdevplatformshell.so.7.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformutil" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformutil APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformutil PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kcmutils;KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformutil.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformutil.so.7"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformutil )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformutil "/usr/local/kde4/lib/libkdevplatformutil.so.7.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformoutputview" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformoutputview APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformoutputview PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces;KDevPlatformImport__kdevplatformutil"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformoutputview.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformoutputview.so.7"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformoutputview )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformoutputview "/usr/local/kde4/lib/libkdevplatformoutputview.so.7.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformvcs" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformvcs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformvcs PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDE4__kparts;KDevPlatformImport__kdevplatformutil;KDevPlatformImport__kdevplatformproject;KDevPlatformImport__kdevplatformlanguage"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformoutputview;KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformvcs.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformvcs.so.7"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformvcs )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformvcs "/usr/local/kde4/lib/libkdevplatformvcs.so.7.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformdebugger" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformdebugger APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformdebugger PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__ktexteditor"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces;KDevPlatformImport__kdevplatformutil"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformdebugger.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformdebugger.so.7"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformdebugger )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformdebugger "/usr/local/kde4/lib/libkdevplatformdebugger.so.7.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformdocumentation" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformdocumentation APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformdocumentation PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformdocumentation.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformdocumentation.so.7"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformdocumentation )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformdocumentation "/usr/local/kde4/lib/libkdevplatformdocumentation.so.7.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformtests" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformtests APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformtests PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformshell;KDevPlatformImport__kdevplatformlanguage;KDevPlatformImport__kdevplatformproject"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformtests.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformtests.so.7"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformtests )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformtests "/usr/local/kde4/lib/libkdevplatformtests.so.7.0.0" )

# Make sure the targets which have been exported in some other 
# export set exist.

# Import target "KDevPlatformImport__kdevplatformjsontests" for configuration "Release"
SET_PROPERTY(TARGET KDevPlatformImport__kdevplatformjsontests APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
SET_TARGET_PROPERTIES(KDevPlatformImport__kdevplatformjsontests PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "qjson;KDevPlatformImport__kdevplatformlanguage"
  IMPORTED_LOCATION_RELEASE "/usr/local/kde4/lib/libkdevplatformjsontests.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformjsontests.so.7"
  )

LIST(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformjsontests )
LIST(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformjsontests "/usr/local/kde4/lib/libkdevplatformjsontests.so.7.0.0" )

# Loop over all imported files and verify that they actually exist
FOREACH(target ${_IMPORT_CHECK_TARGETS} )
  FOREACH(file ${_IMPORT_CHECK_FILES_FOR_${target}} )
    IF(NOT EXISTS "${file}" )
      MESSAGE(FATAL_ERROR "The imported target \"${target}\" references the file
   \"${file}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    ENDIF()
  ENDFOREACH()
  UNSET(_IMPORT_CHECK_FILES_FOR_${target})
ENDFOREACH()
UNSET(_IMPORT_CHECK_TARGETS)

# Commands beyond this point should not need to know the version.
SET(CMAKE_IMPORT_FILE_VERSION)
